Subject: Let "nmakehlp -V" start searching digits after the found match (suggested by Harald Oehlmann)

From: "jan.nijtmans" <[email-masked]>
Date: Wed, 19 Sep 2012 12:33:25 +0000

---
 ChangeLog      | 4 +++-
 win/nmakehlp.c | 9 +++++----
 2 files changed, 8 insertions(+), 5 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index b6addcc..9a17845 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,7 +1,9 @@
 2012-09-19  Jan Nijtmans  <[email-masked]>
 
-	* generic/tcl.h: make Tcl_Interp a fully opaque structure
+	* generic/tcl.h:  make Tcl_Interp a fully opaque structure
 	if TCL_NO_DEPRECATED is set (TIP 330 and 336).
+	* win/nmakehlp.c: Let "nmakehlp -V" start searching digits
+	after the found match (suggested by Harald Oehlmann)
 
 2012-09-07  Harald Oehlmann  <[email-masked]>
 
diff --git a/win/nmakehlp.c b/win/nmakehlp.c
index d0edcf0..b1a1517 100644
--- a/win/nmakehlp.c
+++ b/win/nmakehlp.c
@@ -498,9 +498,10 @@ GetVersionFromFile(
 	    p = strstr(szBuffer, match);
 	    if (p != NULL) {
 		/*
 		 * Skip to first digit.
 		 */
 
+		p += strlen(match);
 		while (*p && !isdigit(*p)) {
 		    ++p;
 		}
@@ -630,11 +631,11 @@ SubstituteFile(
 	    }
 	}
 #endif
-	
+
 	/*
 	 * Run the substitutions over each line of the input
 	 */
-	
+
 	while (fgets(szBuffer, cbBuffer, fp) != NULL) {
 	    list_item_t *p = NULL;
 	    for (p = substPtr; p != NULL; p = p->nextPtr) {
@@ -654,7 +655,7 @@ SubstituteFile(
 	    }
 	    printf(szBuffer);
 	}
-	
+
 	list_free(&substPtr);
     }
     fclose(fp);
@@ -498,9 +498,10 @@ GetVersionFromFile(
 	    if (p != NULL) {
 		/*
-		 * Skip to first digit.
+		 * Skip to first digit after the match.
 		 */
 
-- 
cgit v0.12